'MORQUIET.BAS
'INDFMT(2,32)
'Unlike the program, MORSE.BAS, this variation does not make audible BEEPs,
' so runs much faster without the delay of making the sounds.
'Creates ASCII txt file showing only the codes but no text.
'                  Written by Edwin M. Kiser  03/17/2003

'Feel free to distribute to anyone that may be interested.

'An ASCII text file, "MORSTEST.TXT", will have all the codes produced
' in this session.  These may be printed, and used as a visual drill.

'If there is already existing a file called "MORSTEST.TXT", the codes
' produced in this session will be appended to the end of the existing
' material already in that file.  If the results of this run are to be
' kept as a separate file, then delete (or rename it if you want to keep it)
' the previously existing file before running this MORQUIET.BAS program.

DEFINT I                       'all variables beginning with "i" are INTEGER
DEFSTR S                       'all variables beginning with "s" are STRING

CLS                            'start with the screen CLEAR SCREEN


'--------------DEFINING THE SPEED OF THE TRANSMISSION-----------------
'The following two settings may need to be made larger during the learning
' process.  These effect the time of the silence, not the char itself.

CONST iENDCHARVAL = 20         'length of pause after each char
                               ' officially should be 3
                               ' originally set to '20' (rather slow)

CONST iENDWORDVAL = 30         'length of pause after each word
                               ' officially should be 7
                               ' originally set to '30' (very slow)

'The "iT" value below defines how fast each char is sent.  The larger
' the number, the faster is the transmission speed.
'Try several values: 12 for very slow, and 32 for really fast, with
' other values in between to suit your abilities to receive.

CONST iT = 24                  'sets the timing of rate of transmission
                               ' of each character
                               ' originally set to '24' (medium speed)

'Try to get used to the sound of each character sent as a rather rapid
' sequence of dots and dashes.  The length of the silence
' can be increased to facilitate the learner's time for reaction.
'  (see iENDCHARVAL and iENDWORDVAL above for silence definition)

'THE ABOVE CONSTANTS:
'  iT, iENDCHARVAL, AND iENDWORDVAL,
'ARE THE ONLY VALUES YOU SHOULD PLAY AROUND WITH.
'LEAVE THE REST OF THIS STUFF ALONE, AS IT (hopefully) WORKS FINE AS IS.
'EXPERIMENT WITH THESE CONSTANT SETTINGS AND SEE THE RESULTS.
'SET IT UP TO MATCH YOUR OWN LEVEL OF SKILL.

'-------------TRANSMISSION SPEED NOW DEFINED--------------------------

'Timing is done through the use of the PLAY command that allows for
' the specification of the length of each note to be played.  The
' PLAY command also allows for the playing of a SILENT note to give
' the effect of a pause between parts of the audible transmission.
'The DOT and DASH is done by the playing of a single note, the tone
' of which is determined by sPITCH (below), with the length of that
' note being used to distinguish DOT from DASH.
'In preparation for using the PLAY command, we set up certain
' parameters to be handed to PLAY:

sTRT = STR$(iT)                'define time for dot
iTT = iT \ 3                   'define time for dash
                               ' the time of the DASH is supposed
                               ' to be THREE times that of the DOT
sTRTT = STR$(iTT)

'get these time delay values into a command string format suitable
' to be passed to the PLAY function:

sDOTTIME = "L" + RIGHT$(sTRT, LEN(sTRT) - 1)
sDASHTIME = "L" + RIGHT$(sTRTT, LEN(sTRTT) - 1)

sPITCH = "C"                   'pitch of tone generated (in range A-G)
sQUIET = "N0"                  'the SILENT note
'--------------PARAMETERS TO BE PASSED TO "PLAY" NOW SET-------------
iFALSE = 0
iTRUE = NOT iFALSE

sCRLF = CHR$(13) + CHR$(10)    'carriage return + line feed
sQUOTE = CHR$(34)              'double quote ( " )
sALPHA = "ABCDEFGHIJKLMNOPQRSTUVWXYZ. ,?0123456789:-`'/()" + sQUOTE'supported characters

sDOT = "."
sDASH = "-"
sSPACE = "  "                  'space after a char on 'sTXTFIL' file

sTXTFIL = "MORSTEST.TXT"       'the name of the file to keep the codes
OPEN sTXTFIL FOR APPEND AS #1  'prepare file to receive codes

PRINT "Specify text to be transmitted:"'prompt for text of message

LINE INPUT sL                  'Read a line of text from console
DO
: iSAVECH = iTRUE              'Record this line in code
: iCHARCNT = 0                 'reset char counter for new line

: sL = UCASE$(sL)              'make everything upper case
: DO
: : PRINT                      'start a new line
: : FOR I = 1 TO LEN(sL)       'step thru each char of message
: : : sCHAR = MID$(sL, I, 1)   'get next char from msg
: : : PRINT sCHAR;             'display the msg to be sounded
: : : iPTR = INSTR(sALPHA, sCHAR)'translate char to ordinal position
: : : IF iPTR THEN             'if char is in supported listing
: : : : ON iPTR GOSUB A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, PERIOD, SPACHAR, COMMA, QUESTION, ZERO, ONE, TWO, THREE, FOUR, FIVE, SIX, SEVEN, EIGHT, NINE, CO, HY, AP, AP, SLASH, PA, PA, QU
: : : : GOSUB ENDCHAR          'terminate char with some silence
: : : END IF

: : NEXT I                     'go do next char from msg
: : PRINT                      'finished with msg, get new line
: : 'PRINT "Hit just ENTER to repeat msg, or"
: : 'PRINT "a new message text ending with ENTER, or"
: : 'PRINT "* then Enter to QUIT: "
: : LINE INPUT sAGAIN          'read operator's reply
: : iSAVECH = iFALSE           'don't record multiply tries
: LOOP WHILE LEN(sAGAIN) = 0   'if just ENTER, repeat msg

: IF LEFT$(sAGAIN, 1) = "*" THEN 'if * found, quit
: : EXIT DO
: END IF
: PRINT #1, sCRLF              'finish this line of code + blank line

: sL = sAGAIN                  'pass on new message text
LOOP
PRINT #1, sCRLF                'end file with blank line
CLOSE #1                       'finished with code file
CLS
PRINT "FILE: MORSTEST.TXT has the Morse codes for these messages."
SYSTEM                         'return to operating system

'----------------------------------
A:                             '.-
GOSUB DOT: GOSUB DASH
RETURN

B:                             '-...
GOSUB DASH: GOSUB DOT: GOSUB DOT: GOSUB DOT
RETURN

C:                             '-.-.
GOSUB DASH: GOSUB DOT: GOSUB DASH: GOSUB DOT
RETURN

D:                             '-..
GOSUB DASH: GOSUB DOT: GOSUB DOT
RETURN

E:                             '.
GOSUB DOT
RETURN

F:                             '..-.
GOSUB DOT: GOSUB DOT: GOSUB DASH: GOSUB DOT
RETURN

G:                             '--.
GOSUB DASH: GOSUB DASH: GOSUB DOT
RETURN

H:                             '....
GOSUB DOT: GOSUB DOT: GOSUB DOT: GOSUB DOT
RETURN

I:                             '..
GOSUB DOT: GOSUB DOT
RETURN

J:                             '.---
GOSUB DOT: GOSUB DASH: GOSUB DASH: GOSUB DASH
RETURN

K:                             '-.-
GOSUB DASH: GOSUB DOT: GOSUB DASH
RETURN

L:                             '.-..
GOSUB DOT: GOSUB DASH: GOSUB DOT: GOSUB DOT
RETURN

M:                             '--
GOSUB DASH: GOSUB DASH
RETURN

N:                             '-.
GOSUB DASH: GOSUB DOT
RETURN

O:                             '---
GOSUB DASH: GOSUB DASH: GOSUB DASH
RETURN

P:                             '.--.
GOSUB DOT: GOSUB DASH: GOSUB DASH: GOSUB DOT
RETURN

Q:                             '--.-
GOSUB DASH: GOSUB DASH: GOSUB DOT: GOSUB DASH
RETURN

R:                             '.-.
GOSUB DOT: GOSUB DASH: GOSUB DOT
RETURN

S:                             '...
GOSUB DOT: GOSUB DOT: GOSUB DOT
RETURN

T:                             '-
GOSUB DASH
RETURN

U:                             '..-
GOSUB DOT: GOSUB DOT: GOSUB DASH
RETURN

V:                             '...-
GOSUB DOT: GOSUB DOT: GOSUB DOT: GOSUB DASH
RETURN

W:                             '.--
GOSUB DOT: GOSUB DASH: GOSUB DASH
RETURN

X:                             '-..-
GOSUB DASH: GOSUB DOT: GOSUB DOT: GOSUB DASH
RETURN

Y:                             '-.--
GOSUB DASH: GOSUB DOT: GOSUB DASH: GOSUB DASH
RETURN

Z:                             '--..
GOSUB DASH: GOSUB DASH: GOSUB DOT: GOSUB DOT
RETURN

PERIOD:                        '.-.-.- (in the UK, called "full stop")
GOSUB DOT: GOSUB DASH: GOSUB DOT: GOSUB DASH: GOSUB DOT: GOSUB DASH
RETURN

SPACHAR:                       'END OF WORD-delay
FOR iREPEAT = 1 TO iENDWORDVAL
: GOSUB PAUSE
NEXT iREPEAT

PRINT #1, sSPACE;
iCHARCNT = iCHARCNT + LEN(sSPACE)
RETURN

COMMA:                         '--..--
GOSUB DASH: GOSUB DASH: GOSUB DOT: GOSUB DOT: GOSUB DASH: GOSUB DASH
RETURN

QUESTION:                      '..--..
GOSUB DOT: GOSUB DOT: GOSUB DASH: GOSUB DASH: GOSUB DOT: GOSUB DOT
RETURN

ZERO:                          '-----
GOSUB DASH: GOSUB DASH: GOSUB DASH: GOSUB DASH: GOSUB DASH
RETURN

ONE:                           '.----
GOSUB DOT: GOSUB DASH: GOSUB DASH: GOSUB DASH: GOSUB DASH
RETURN

TWO:                           '..---
GOSUB DOT: GOSUB DOT: GOSUB DASH: GOSUB DASH: GOSUB DASH
RETURN

THREE:                         '...--
GOSUB DOT: GOSUB DOT: GOSUB DOT: GOSUB DASH: GOSUB DASH
RETURN

FOUR:                          '....-
GOSUB DOT: GOSUB DOT: GOSUB DOT: GOSUB DOT: GOSUB DASH
RETURN

FIVE:                          '.....
GOSUB DOT: GOSUB DOT: GOSUB DOT: GOSUB DOT: GOSUB DOT
RETURN

SIX:                           '-....
GOSUB DASH: GOSUB DOT: GOSUB DOT: GOSUB DOT: GOSUB DOT
RETURN

SEVEN:                         '--...
GOSUB DASH: GOSUB DASH: GOSUB DOT: GOSUB DOT: GOSUB DOT:
RETURN

EIGHT:                         '---..
GOSUB DASH: GOSUB DASH: GOSUB DASH: GOSUB DOT: GOSUB DOT:
RETURN

NINE:                          '----.
GOSUB DASH: GOSUB DASH: GOSUB DASH: GOSUB DASH: GOSUB DOT
RETURN

CO:                            '---... (COLON)
GOSUB DASH: GOSUB DASH: GOSUB DASH: GOSUB DOT: GOSUB DOT: GOSUB DOT
RETURN

HY:                            '-....- (HYPHEN)
GOSUB DASH: GOSUB DOT: GOSUB DOT: GOSUB DOT: GOSUB DOT: GOSUB DASH
RETURN

AP:                            '.----. (APOSTROPHE)
GOSUB DOT: GOSUB DASH: GOSUB DASH: GOSUB DASH: GOSUB DASH: GOSUB DOT
RETURN

SLASH:                         '-..-. (SLASH)
GOSUB DASH: GOSUB DOT: GOSUB DOT: GOSUB DASH: GOSUB DOT
RETURN

PA:                            '-.--.- (PARENTHESIS - EITHER ONE)
GOSUB DASH: GOSUB DOT: GOSUB DASH: GOSUB DASH: GOSUB DOT: GOSUB DASH
RETURN

QU:                            '.-..-. (DOUBLE QUOTE)
GOSUB DOT: GOSUB DASH: GOSUB DOT: GOSUB DOT: GOSUB DASH: GOSUB DOT
RETURN

'--------------------------------
'In this next section, we drive the PLAY command to use the PC speaker
' to generate both the sounds and the silent pauses between sounds
' to emulate the effect of sending audible MORSE CODE.
'Each PLAY command has two parms: the TIMING, and the NOTE.
'The timing is defined as either "eONETIME" or "eTWOTIME".
'The NOTE is either the audible "sPITCH" or the pause "sQUIET".

DOT:
'PLAY sDOTTIME + sPITCH         'generate s SHORT sound
FOR iREPEAT = 1 TO 2
: GOSUB PAUSE
NEXT iREPEAT

sCODECHAR = sDOT               'code item is a dot
GOSUB SAVECODE                 'record this code item

RETURN

DASH:
'PLAY sDASHTIME + sPITCH        'generate a LONG sound
FOR iREPEAT = 1 TO 1
: GOSUB PAUSE
NEXT iREPEAT

sCODECHAR = sDASH              'code item is a dash
GOSUB SAVECODE                 'record this code item

RETURN

ENDCHAR:                       'END OF CHAR-delay
FOR iREPEAT = 1 TO iENDCHARVAL
: GOSUB PAUSE
NEXT iREPEAT

PRINT #1, sSPACE;              'code item is a space to end this char
IF iCHARCNT > 60 THEN          'if this line is full,
: iCHARCNT = 0                 'reset char counter for this line
: PRINT #1, sCRLF              'end this line + blank line
ELSE                           'since line is not full
: iCHARCNT = iCHARCNT + LEN(sSPACE)'bump the counter of characters on this line
END IF

RETURN

PAUSE:                         'the pause after a DOT or DASH
'PLAY sDOTTIME + sQUIET         'the SILENT note
RETURN

SAVECODE:
IF iSAVECH THEN
: PRINT #1, sCODECHAR;         'record this code item
: iCHARCNT = iCHARCNT + 1      'bump the counter of characters on this line
END IF
RETURN
'-------------END OF PROGRAM - MORSE.BAS---------------------

